@@ -1,5 +1,5 @@
 # SPDX-FileCopyrightText: 2017 Scott Shawcroft, written for Adafruit Industries
-# SPDX-FileCopyrightText: Copyright (c) 2021 Dylan Herrada for Adafruit Industries
+# SPDX-FileCopyrightText: Copyright (c) 2021 Eva Herrada for Adafruit Industries
 #
 # SPDX-License-Identifier: MIT
 """
@@ -9,7 +9,7 @@
 CircuitPython library for running DuckyScript
 
 
-* Author(s): Dylan Herrada
+* Author(s): Eva Herrada
 
 Implementation Notes
 --------------------
@@ -32,7 +32,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.0.5"
+__version__ = "1.0.7"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Ducky.git"
 
 commands = {
